/*  -- translated by f2c (version 20090411).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__24 = 24;
static integer c__8 = 8;
static integer c_n8 = -8;
static integer c_n24 = -24;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int bswp4_(integer *ix1, integer *ix2)
{
    /* Initialized data */

    static integer im1 = 255;
    static integer im2 = 65280;
    static integer im3 = 16711680;
    static integer im4 = 4278190080;

    /* System generated locals */
    integer i__1, i__2, i__3, i__4;

    /* Local variables */
    extern integer ishift_(integer *, integer *);

    i__1 = *ix1 & im1;
    i__2 = *ix1 & im2;
    i__3 = *ix1 & im3;
    i__4 = *ix1 & im4;
    *ix2 = ishift_(&i__1, &c__24) | ishift_(&i__2, &c__8) | (ishift_(&i__3, &
	    c_n8) | ishift_(&i__4, &c_n24));
    return 0;
} /* bswp4_ */

